unit CallPickUpDlg;

Interface

uses
  Winapi.Windows, Winapi.Messages, System.SysUtils, System.Variants, System.Classes, Vcl.Graphics,
  Vcl.Controls, Vcl.Forms, Vcl.Dialogs,

  StoreCallPickUp, StoreUser,

  VaxCallPickUp,
  VaxServerSIP, Vcl.ExtCtrls, Vcl.StdCtrls;


type
  TCallPickUpForm = class(TForm)

  GroupBox1: TGroupBox;
  GroupBox2: TGroupBox;

  Label1: TLabel;
  Label2: TLabel;

  ComboGroupName: TComboBox;
  ComboUserLogin: TComboBox;
    ListPickUpGroupMember: TListBox;

  BtnAddGroup: TButton;
  BtnRemoveGroup: TButton;
  BtnClearGroup: TButton;

  BtnAddMember: TButton;
  BtnRemoveMember: TButton;
  BtnClearMember: TButton;
  Label4: TLabel;
  Label5: TLabel;

  procedure OnBtnAddGroupClick(Sender: TObject);
  procedure OnBtnRemoveGroupClick(Sender: TObject);

  procedure OnBtnAddMemberClick(Sender: TObject);
  procedure OnBtnRemoveMemberClick(Sender: TObject);
  procedure OnBtnClearMemberClick(Sender: TObject);

  procedure ComboGroupNameChange(Sender: TObject);
  procedure OnBtnClearGroupClick(Sender: TObject);

  private
  procedure FillLogin();
  procedure FillPickUpGroup();

  procedure ClearDlgUI();
  procedure GetMemberNameAll(var objList: TStringList);

  procedure UpdateDlgUI();
  procedure ShowGroupDetails();

  public

  procedure OnSetActive();
  constructor Create(AOwner: TComponent); reintroduce; overload;

end;

var
  CallPickUpForm: TCallPickUpForm;

implementation

{$R *.dfm}

  constructor TCallPickUpForm.create(AOwner: TComponent);
  begin
    inherited Create(AOwner);
  end;


  ////////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////////

  procedure TCallPickUpForm.OnBtnAddGroupClick(Sender: TObject);
  var
    bIsUpdated: Boolean;
    objMemberList: TStringList;
  begin

    if(ComboGroupName.Text = '') then
    begin
      ShowMessage('Please enter a valid group name.');
      Exit();
    end;

    bIsUpdated := False;

	  if(ComboGroupName.Items.IndexOf(ComboGroupName.Text) <> -1) then
    begin
      if MessageDlg('PickUp group already exists, do you want to continue?', mtConfirmation, [mbYes, mbNo], 0, mbNo) = mrNo then
      begin
        Exit();
      end;

      bIsUpdated := True;
    end;

    objMemberList :=  TStringList.Create();
    GetMemberNameAll(objMemberList);

	  if(TVaxCallPickUp.AddCallPickUpGroup(ComboGroupName.Text, objMemberList) = False) then
    begin
      ShowMessage('Unable to add pickup group.');
      Exit();
    end;

    if(ComboGroupName.Items.IndexOf(ComboGroupName.Text) = -1) Then
      ComboGroupName.Items.Add(ComboGroupName.Text);

    if bIsUpdated then
      ShowMessage('Pickup group updated successfully.')
    else
      ShowMessage('Pickup group added successfully.');

  end;

  ////////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////////

  procedure TCallPickUpForm.OnBtnRemoveGroupClick(Sender: TObject);
  begin

    TVaxCallPickUp.RemoveCallPickUpGroup(ComboGroupName.Text);

    ListPickUpGroupMember.Clear();
    ComboGroupName.Items.Delete(ComboGroupName.Items.IndexOf(ComboGroupName.Text));

  end;

  ////////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////////

  procedure TCallPickUpForm.OnBtnClearGroupClick(Sender: TObject);
  begin
    ClearDlgUI();
  end;

  ////////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////////

  procedure TCallPickUpForm.FillLogin();
  var
    objList: TStringList;
    sUserName: string;
  begin

    ComboUserLogin.Clear();

    objList := TStringList.Create();
    TStoreUser.GetUserAll(objList);

    for sUserName in objList do
    begin
      ComboUserLogin.Items.Add(sUserName);
    end;

    ComboUserLogin.ItemIndex := 0;

  end;

  ////////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////////

  procedure TCallPickUpForm.FillPickUpGroup();
  var
    objList: TStringList;
    sGroupName: string;
  begin

    ComboGroupName.Items.Clear();

    objList := TStringList.Create();
    TStoreCallPickUp.GetGroupNameAll(objList);

    for sGroupName in objList do
    begin
      ComboGroupName.Items.Add(sGroupName);
    end;

    ComboGroupName.ItemIndex := 0;

  end;

  ////////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////////

  procedure TCallPickUpForm.OnBtnAddMemberClick(Sender: TObject);
  var
    sMemberName: string;
  begin
    sMemberName := ComboUserLogin.Text;

    if(ListPickUpGroupMember.Items.IndexOf(sMemberName) <> -1) Then
      Exit();

    ListPickUpGroupMember.Items.Insert(0, sMemberName);
  end;

  procedure TCallPickUpForm.OnBtnClearMemberClick(Sender: TObject);
  begin
    ListPickUpGroupMember.Clear();
  end;

  ////////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////////

  procedure TCallPickUpForm.ClearDlgUI();
  begin

   ComboGroupName.Text := '';
   ListPickUpGroupMember.Clear();

  end;

  procedure TCallPickUpForm.GetMemberNameAll(var objList: TStringList);
  var
    sAgentName: String;
  begin

    for sAgentName in ListPickUpGroupMember.Items do
    begin
      objList.Add(sAgentName);
    end;

  end;

  ////////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////////

  procedure TCallPickUpForm.ShowGroupDetails();
  var
    objMemberList: TStringList;
    sMemberName: string;
  begin

    if(ComboGroupName.Text = '') then
    begin
      Exit();
    end;

    objMemberList := TStringList.Create();
    TStoreCallPickUp.GetGroup(ComboGroupName.Text, objMemberList);

    ListPickUpGroupMember.Clear();

    for sMemberName in objMemberList do
    begin
      ListPickUpGroupMember.Items.Add(sMemberName);
    end;

  end;

  ////////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////////

  procedure TCallPickUpForm.OnBtnRemoveMemberClick(Sender: TObject);
  var
    nIndex: Integer;
    sMemberName: string;
  begin
    for nIndex:= ListPickUpGroupMember.Items.count -1 downto 0 do
      if ListPickUpGroupMember.selected[nIndex] then
      begin
        sMemberName := ListPickUpGroupMember.Items[nIndex];
        ListPickUpGroupMember.Items.delete(nIndex);
      end;
  end;

  ////////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////////

  procedure TCallPickUpForm.ComboGroupNameChange(Sender: TObject);
  begin
    ShowGroupDetails();
  end;

  ////////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////////

  procedure TCallPickUpForm.UpdateDlgUI();
  begin
    FillPickUpGroup();
    FillLogin();
    ShowGroupDetails()
  end;

  procedure TCallPickUpForm.OnSetActive();
  begin
    UpdateDlgUI();
  end;

end.
