unit QueueDlg;

Interface

uses
  Winapi.Windows,
  Winapi.Messages,
  System.SysUtils,
  System.Variants,
  System.Classes,
  Vcl.Graphics,
  Vcl.Controls,
  Vcl.Forms,
  Vcl.Dialogs,

  StoreQueue, StoreUser,

  VaxQueue,
  VaxServerSIP, VaxServerCOM, VaxDefine, Vcl.ExtCtrls, Vcl.StdCtrls;

type
  TQueueForm = class(TForm)

  GroupBox1: TGroupBox;
  GroupBox2: TGroupBox;

  Label1: TLabel;
  Label2: TLabel;
    ComboQueueName: TComboBox;
    ComboProcessMode: TComboBox;

  Label3: TLabel;
    ComboAgentName: TComboBox;
    ListQueueAgent: TListBox;

  btnAddAgent: TButton;
  btnRemoveAgent: TButton;

  btnClearAgent: TButton;
  btnAddQueue: TButton;
  btnRemoveQueue: TButton;
  btnClearDlg: TButton;
    Label4: TLabel;
    ComboProcessType: TComboBox;
    GroupBox3: TGroupBox;
    Label5: TLabel;
    EditQueueMusicFile: TEdit;
    Label6: TLabel;
    EditQueueDialToneFile: TEdit;

  procedure ComboQueueNameChange(Sender: TObject);

  procedure OnBtnAddQueueClick(Sender: TObject);
  procedure OnBtnRemoveQueueClick(Sender: TObject);
  procedure OnBtnClearQueueClick(Sender: TObject);

  procedure OnBtnAddAgentClick(Sender: TObject);
  procedure OnBtnRemoveAgentClick(Sender: TObject);
  procedure OnBtnClearAgentClick(Sender: TObject);

  private
  function AddQueueChecks(): Boolean;
  function GetProcessMode(): Integer;
  function GetProcessType(): Integer;

  procedure AddUsers();
  procedure AddQueue();

  procedure AddProcessMode();
  procedure AddProcessType();

  procedure ClearDlgUI();
  procedure GetAgentNameAll(var objList: TStringList);

  procedure UpdateDlgUI();
  procedure ShowQueueDetails();

  public
  constructor Create(AOwner: TComponent); reintroduce; overload;

  public
  procedure OnSetActive();

end;

var
  QueueForm: TQueueForm;

implementation

{$R *.dfm}

  ////////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////////

  constructor TQueueForm.create(AOwner: TComponent);
  begin
    inherited Create(AOwner);
  end;

  ////////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////////

  procedure TQueueForm.OnBtnAddQueueClick(Sender: TObject);
  var
    sQueueName: string;
    bIsUpdated: Boolean;
    objAgentList: TStringList;
  begin

	  if(AddQueueChecks() = False) Then
    begin
      Exit();
    end;

    bIsUpdated := False;
    sQueueName := ComboQueueName.Text;

    if(ComboQueueName.Items.IndexOf(sQueueName) <> -1) Then
    begin
      if MessageDlg('Queue already exists, do you want to continue?', mtConfirmation, [mbYes, mbNo], 0, mbNo) = mrNo Then
      begin
        Exit();
      end;

      bIsUpdated := True;
    end;

    objAgentList :=  TStringList.Create();
    GetAgentNameAll(objAgentList);

    if(TVaxQueue.AddQueue(sQueueName, GetProcessMode(), GetProcessType(), objAgentList, EditQueueMusicFile.Text, EditQueueDialToneFile.Text) <> True) Then
    begin
      ShowMessage('Unable to add queue.');
      Exit();
    end;

    if(ComboQueueName.Items.IndexOf(sQueueName) = -1) Then
       ComboQueueName.Items.Add(sQueueName);

    if bIsUpdated Then
      ShowMessage('Queue updated successfully.')
    else
      ShowMessage('Queue added successfully.');

  end;

  ////////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////////

  procedure TQueueForm.OnBtnRemoveQueueClick(Sender: TObject);
  begin

    if(Length(ComboQueueName.Text) = 0) Then
    begin
      Exit();
    end;

    TVaxQueue.RemoveQueue(ComboQueueName.Text);
    ComboQueueName.Items.delete(ComboQueueName.ItemIndex);

    ClearDlgUI();

    if(ComboQueueName.Items.Count > 0) Then
      ComboQueueName.ItemIndex := 0;

    ShowQueueDetails();
    ShowMessage('Queue Removed Successfully!');

  end;

  ////////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////////

  procedure TQueueForm.OnBtnClearQueueClick(Sender: TObject);
  begin
     ClearDlgUI();
  end;

  ////////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////////

  procedure TQueueForm.ShowQueueDetails();
  var
    objAgentNameList: TStringList;
    sAgentName: string;
    nProcessMode, nProcessType: Integer;
    sQueueMusicFile, sQueueDialToneFile: String;
  begin

    if(Length(ComboQueueName.Text) = 0) Then
    begin
      Exit();
    end;

    objAgentNameList := TStringList.Create();

    if(TStoreQueue.GetQueue(ComboQueueName.Text, nProcessMode, nProcessType, objAgentNameList, sQueueMusicFile, sQueueDialToneFile) = False) Then
    begin
      Exit();
    end;

    if(ComboProcessMode.Items.Count > 0) Then
      ComboProcessMode.ItemIndex := nProcessMode;

    if(ComboProcessType.Items.Count > 0) Then
      ComboProcessType.ItemIndex := nProcessType;

    EditQueueMusicFile.Text := sQueueMusicFile;
    EditQueueDialToneFile.Text := sQueueDialToneFile;

    ListQueueAgent.Clear();

    for sAgentName in objAgentNameList do
    begin
      ListQueueAgent.Items.Add(sAgentName);
    end;

  end;

  ////////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////////

  procedure TQueueForm.ComboQueueNameChange(Sender: TObject);
  begin
    ShowQueueDetails()
  end;

  ////////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////////

  function TQueueForm.AddQueueChecks(): Boolean;
  begin

    if(ComboQueueName.Text  = '') Then
    begin
      ShowMessage('Please enter Queue Name');
      Exit(False);
    end;

    if(ComboProcessMode.Text = '') Then
    begin
      ShowMessage('Please select Process Mode');
      Exit(False);
    end;

    if(ComboProcessType.Text = '') Then
    begin
      ShowMessage('Please select Process Mode Type Free/Any');
      Exit(False);
    end;

    Result := True;

  end;

  ////////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////////

  function TQueueForm.GetProcessMode(): Integer;
  begin
    Result := ComboProcessMode.ItemIndex;
  end;

  function TQueueForm.GetProcessType(): Integer;
  begin
    Result := ComboProcessType.ItemIndex;
  end;

  ////////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////////

  procedure TQueueForm.AddUsers();
  var
    objLoginList: TStringList;
    sAgentName: string;
  begin

    objLoginList := TStringList.Create();
    TStoreUser.GetUserAll(objLoginList);

    ComboAgentName.Clear();

    for sAgentName in objLoginList do
    begin
      ComboAgentName.Items.Add(sAgentName);
    end;

    ComboAgentName.ItemIndex := 0;

  end;

  ////////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////////

  procedure TQueueForm.AddQueue();
  var
    objQueueList: TStringList;
    sQueueName: string;
  begin

    if(ComboQueueName.Items.Count > 0) Then
      ComboQueueName.Clear;

    objQueueList := TStringList.Create();
    TStoreQueue.GetQueueNameAll(objQueueList);

    for sQueueName in objQueueList do
    begin
      ComboQueueName.Items.Add(sQueueName);
    end;

    if(ComboQueueName.Items.Count > 0) Then
      ComboQueueName.ItemIndex := 0;

  end;

  ////////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////////

  procedure TQueueForm.AddProcessMode();
  begin

    ComboProcessMode.Clear();

    ComboProcessMode.Items.Add(TVaxDefine.GROUP_ALGO_RING_ALL);
    ComboProcessMode.Items.Add(TVaxDefine.GROUP_ALGO_HUNT_RANDOM);
    ComboProcessMode.Items.Add(TVaxDefine.GROUP_ALGO_ROUND_ROBIN);
    ComboProcessMode.Items.Add(TVaxDefine.GROUP_ALGO_LEAST_ANSWERED);
    ComboProcessMode.Items.Add(TVaxDefine.GROUP_ALGO_LEAST_TALK_TIME);
    ComboProcessMode.Items.Add(TVaxDefine.GROUP_ALGO_LONGEST_WAITING);
    ComboProcessMode.Items.Add(TVaxDefine.GROUP_ALGO_PRIORITIZED_HUNT);

    ComboProcessMode.ItemIndex := 0;

  end;

  procedure TQueueForm.AddProcessType();
  begin

    ComboProcessType.Clear();

    ComboProcessType.Items.Add(TVaxDefine.GROUP_ALGO_MODE_TYPE_FREE);
    ComboProcessType.Items.Add(TVaxDefine.GROUP_ALGO_MODE_TYPE_ANY);

    ComboProcessType.ItemIndex := 0;

  end;

  ////////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////////

  procedure TQueueForm.OnBtnAddAgentClick(Sender: TObject);
  var
    sAgentName: string;
  begin
    sAgentName := ComboAgentName.Text;

    if(ListQueueAgent.Items.IndexOf(sAgentName) <> -1) Then
      Exit();

    ListQueueAgent.Items.Insert(0, sAgentName);
  end;

  ////////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////////

  procedure TQueueForm.OnBtnClearAgentClick(Sender: TObject);
  begin
    ListQueueAgent.Clear();
  end;

  ////////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////////

  procedure TQueueForm.OnBtnRemoveAgentClick(Sender: TObject);
  var
    nIndex: Integer;
    sAgentName: string;
  begin
    for nIndex:= ListQueueAgent.Items.count -1 downto 0 do
      if ListQueueAgent.selected[nIndex] Then
      begin
        sAgentName := ListQueueAgent.Items[nIndex];
        ListQueueAgent.Items.delete(nIndex);
      end;
  end;

  procedure TQueueForm.ClearDlgUI();
  begin

    ComboQueueName.Text := '';

    if(ComboProcessMode.Items.Count > 0) Then
      ComboProcessMode.ItemIndex := 0;

    if(ComboProcessType.Items.Count > 0) Then
      ComboProcessType.ItemIndex := 0;

    if(ComboAgentName.Items.Count > 0) Then
      ComboAgentName.ItemIndex := 0;

    EditQueueMusicFile.Text := '';
    EditQueueDialToneFile.Text := '';

    ListQueueAgent.Clear;

  end;

  procedure TQueueForm.GetAgentNameAll(var objList: TStringList);
  var
    sAgentName: String;
  begin

    for sAgentName in ListQueueAgent.Items do
    begin
      objList.Add(sAgentName);
    end;

  end;

  ////////////////////////////////////////////////////////////////////////////////
  ////////////////////////////////////////////////////////////////////////////////

  procedure TQueueForm.UpdateDlgUI();
  begin
    AddQueue();
    AddUsers();

    AddProcessMode();
    AddProcessType();

    ShowQueueDetails();
  end;

  procedure TQueueForm.OnSetActive();
  begin
    UpdateDlgUI();
  end;

end.
