unit VaxCallParking;

Interface
uses

  System.Classes, SysUtils;

type TVaxCallParking = class

  public
  class procedure ResetAll(); static;
  class function LoadMusic(sFileName: String): Boolean; static;

  public
  class procedure OnIncomingCall(nSessionId: Integer; sCallerName: String; sCallerId: String; sDialNo: String; sRouteUID: String); static;
  class procedure OnCallSessionTransferBlind(nTransfererSessionId: Integer; nTransfererChannelId: Integer; sTransferee: String; sTransferTo: String; sRouteUID: String); static;

  private
  class procedure StartMusic(nSessionId: Integer; nChannelId: Integer); static;
  class procedure StopMusic(nSessionId: Integer); static;

end;

implementation

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  Uses VaxServerSIP, VaxServerCOM;
  var m_nMusicCallParkingId: Integer = -1;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TVaxCallParking.ResetAll();
  begin
    m_nMusicCallParkingId := -1;
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class function TVaxCallParking.LoadMusic(sFileName: String) : Boolean;
  begin

    if(m_nMusicCallParkingId <> -1) Then
    begin
      TVaxServerSIP.mVaxSIP.UnLoadWaveID(m_nMusicCallParkingId);
      m_nMusicCallParkingId := -1;
    end;

    m_nMusicCallParkingId := TVaxServerSIP.mVaxSIP.LoadWaveFile(sFileName);

    if(m_nMusicCallParkingId = -1) Then
      Exit(False);

    Result := True;

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TVaxCallParking.OnIncomingCall(nSessionId: Integer; sCallerName: String; sCallerId: String; sDialNo: String; sRouteUID: String);
  begin
    StopMusic(nSessionId);
    TVaxServerSIP.mVaxSIP.AcceptCallSession(nSessionId, sCallerName, sCallerId, sDialNo, '', sRouteUID);
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TVaxCallParking.OnCallSessionTransferBlind(nTransfererSessionId: Integer; nTransfererChannelId: Integer; sTransferee: String; sTransferTo: String; sRouteUID: String);
  var
    nChannelId: Integer;
  begin

    if(TVaxServerSIP.mVaxSIP.AcceptTransferBlind(nTransfererSessionId, sTransferee, sTransferee, sTransferTo, '', sRouteUID, 30) = False) Then
      Exit();

    nChannelId := TVaxServerCOM.VAX_CALL_CHANNEL_ZERO;

    if(nTransfererChannelId = TVaxServerCOM.VAX_CALL_CHANNEL_ZERO) Then
      nChannelId := TVaxServerCOM.VAX_CALL_CHANNEL_ONE;

    StartMusic(nTransfererSessionId, nChannelId);

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TVaxCallParking.StartMusic(nSessionId: Integer; nChannelId: Integer);
  var
    nMusicId: Integer;
  begin

    nMusicId := m_nMusicCallParkingId;

    if(nMusicId = -1) then
      Exit();

    TVaxServerSIP.mVaxSIP.PlayWaveStartToCallSession(nSessionId, nChannelId, nMusicId, True, 0);

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TVaxCallParking.StopMusic(nSessionId: Integer);
  begin

    if(m_nMusicCallParkingId = -1) Then
      Exit();

    TVaxServerSIP.mVaxSIP.PlayWaveStopToCallSession(nSessionId, -1, -1);

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

end.

