unit VaxQueue;

interface

uses

  System.Classes,
  StoreQueue,
  VaxDefine, VaxQueueList;

type TVaxQueue = class

  public
  constructor Create();
  class procedure ResetAll(); static;

  public
  class procedure AddQueueList(sQueueName: String; sMusicFileName: String; sDialToneFileName: String); static;
  class procedure RemoveQueueList(sQueueName: String); static;

  public
  procedure OnIncomingCall(nSessionId: Integer; sCallerName: String; sCallerId: String; sQueueName: String; var bProcessed: Boolean);

  public
  procedure OnQueuePlayWaveStarted(nEventType: Integer; sQueueName: String; nSessionId: Integer);
  procedure OnQueuePlayWaveEnded(nEventType: Integer; sQueueName: String; nSessionId: Integer);

  public
  class function AddQueue(sQueueName: String; nProcessMode: Integer; nProcessType: Integer; objAgentList: TStringList; sMusicFileName: String; sDialToneFileName: String): Boolean; static;
  class procedure RemoveQueue(sQueueName: String); static;
  class procedure LoadQueue();

end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

implementation

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  uses VaxServerSIP, VaxServerCOM;
  var m_objQueueList: TVaxQueueList = nil;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  constructor TVaxQueue.Create();
  begin

    if(m_objQueueList = nil) then
      m_objQueueList := TVaxQueueList.Create();

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TVaxQueue.ResetAll();
  begin

    if(m_objQueueList <> nil) then
    begin
      m_objQueueList.Destroy();
      m_objQueueList := nil;
    end;

    m_objQueueList := TVaxQueueList.Create();

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TVaxQueue.AddQueueList(sQueueName: String; sMusicFileName: String; sDialToneFileName: String);
  var
    nMusicWaveId, nDialToneWaveId: Integer;
  begin
    TVaxQueue.RemoveQueueList(sQueueName);

    nMusicWaveId := TVaxServerSIP.mVaxSIP.LoadWaveFile(sMusicFileName);
    nDialToneWaveId := TVaxServerSIP.mVaxSIP.LoadWaveFile(sDialToneFileName);

    m_objQueueList.AddQueue(sQueueName, nMusicWaveId, nDialToneWaveId);
  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TVaxQueue.RemoveQueueList(sQueueName: String);
  var
    nMusicWaveId, nDialToneWaveId: Integer;
  begin

    nMusicWaveId := m_objQueueList.GetQueueMusicId(sQueueName);
    nDialToneWaveId := m_objQueueList.GetQueueDialToneId(sQueueName);

    TVaxServerSIP.mVaxSIP.UnLoadWaveID(nMusicWaveId);
    TVaxServerSIP.mVaxSIP.UnLoadWaveID(nDialToneWaveId);

    m_objQueueList.RemoveQueue(sQueueName);

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TVaxQueue.OnIncomingCall(nSessionId: Integer; sCallerName: String; sCallerId: String; sQueueName: String; var bProcessed: Boolean);
  begin

    bProcessed := false;

    if(Length(sQueueName) = 0) Then
      Exit();

    if(TVaxServerSIP.mVaxSIP.AddCallSessionToQueue(sQueueName, sCallerName, sCallerId, nSessionId, 20) = False)  Then
      Exit();

    bProcessed := True;

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  procedure TVaxQueue.OnQueuePlayWaveStarted(nEventType: Integer; sQueueName: String; nSessionId: Integer);
  Var
    nQueueMediaId: Integer;
  begin

    if(nEventType = TVaxServerCOM.VAX_QUEUE_PLAY_WAVE_EVENT_TYPE_MUSIC) Then
    Begin
        nQueueMediaId := m_objQueueList.GetQueueMusicId(sQueueName);
        if(nQueueMediaId = -1) Then Exit();

        TVaxServerSIP.mVaxSIP.PlayWaveStartToCallSession(nSessionId, TVaxServerCOM.VAX_CALL_CHANNEL_ZERO, nQueueMediaId, true, 0);
        Exit();
    End;

    nQueueMediaId := m_objQueueList.GetQueueDialToneId(sQueueName);
    if(nQueueMediaId = -1) Then Exit();

    TVaxServerSIP.mVaxSIP.PlayWaveStartToCallSession(nSessionId, TVaxServerCOM.VAX_CALL_CHANNEL_ZERO, nQueueMediaId, true, 0);

  end;

  procedure TVaxQueue.OnQueuePlayWaveEnded(nEventType: Integer; sQueueName: String; nSessionId: Integer);
  begin

    TVaxServerSIP.mVaxSIP.PlayWaveStopToCallSession(nSessionId, -1, -1);

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class function TVaxQueue.AddQueue(sQueueName: String; nProcessMode: Integer; nProcessType: Integer; objAgentList: TStringList; sMusicFileName: String; sDialToneFileName: String): Boolean;
  var
    sAgentName: String;
  begin

    if((TVaxServerSIP.mVaxSIP.IsInitialized() = False) or (Length(sQueueName) = 0)) Then
      Exit(False);

    RemoveQueue(sQueueName);

    Result := TVaxServerSIP.mVaxSIP.AddQueue(sQueueName);
    if Result = False then Exit(False);

    for sAgentName in objAgentList do
    begin
      TVaxServerSIP.mVaxSIP.AddQueueAgent(sQueueName, sAgentName);
    end;

    TVaxServerSIP.mVaxSIP.SetQueueProcessMode(sQueueName, nProcessMode, nProcessType);
    AddQueueList(sQueueName, sMusicFileName, sDialToneFileName);

    TStoreQueue.AddQueue(sQueueName, nProcessMode, nProcessType, objAgentList, sMusicFileName, sDialToneFileName);
    Result := True;

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TVaxQueue.RemoveQueue(sQueueName: String);
  begin

    if((TVaxServerSIP.mVaxSIP.IsInitialized() = False) or (Length(sQueueName) = 0)) Then
      Exit();

    RemoveQueueList(sQueueName);
    TVaxServerSIP.mVaxSIP.RemoveQueue(sQueueName);
    TStoreQueue.RemoveQueue(sQueueName);

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TVaxQueue.LoadQueue();
  var
    sQueueName, sMusicFileName, sDialToneFileName: string;
    nProcessMode, nProcessType: Integer;

    objListQueue: TStringList;
    objAgentList: TStringList;
  begin

    if(TVaxServerSIP.mVaxSIP.IsInitialized() = False) Then
      Exit();

    objListQueue :=  TStringList.Create();
    TStoreQueue.GetQueueNameAll(objListQueue);

    if(objListQueue.Count = 0) Then
      Exit();

    objAgentList :=  TStringList.Create();

     sMusicFileName := ''; sDialToneFileName := '';
     nProcessMode := -1; nProcessType := -1;

    for sQueueName in objListQueue do
    begin
      TStoreQueue.GetQueue(sQueueName, nProcessMode, nProcessType, objAgentList, sMusicFileName, sDialToneFileName);
      AddQueue(sQueueName, nProcessMode, nProcessType, objAgentList, sMusicFileName, sDialToneFileName);
    end;

  end;


end.
