unit VaxRingGroup;

interface

uses

  System.Classes,
  StoreRingGroup;


type TVaxRingGroup = class

  public
  constructor Create(); reintroduce; overload;

  public
  procedure OnIncomingCall(nSessionId: Integer; sCallerName: String; sCallerId: String; sRingGroupName: String; var bProcessed: Boolean);

  public
  class function AddRingGroup(sGroupName: String; nProcessMode: Integer; nProcessType: Integer; objAgentList: TStringList): Boolean; static;
  class procedure RemoveRingGroup(sGroupName: String); static;
  class procedure LoadRingGroup(); static;

end;

implementation

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  uses VaxServerSIP;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  constructor TVaxRingGroup.Create();
  begin
  end;

  procedure TVaxRingGroup.OnIncomingCall(nSessionId: Integer; sCallerName: String; sCallerId: String; sRingGroupName: String; var bProcessed: Boolean);
  begin

    bProcessed := False;

    if(Length(sRingGroupName) = 0) Then
      Exit();

    if(TVaxServerSIP.mVaxSIP.AddCallSessionToRingGroup(sRingGroupName, sCallerName, sCallerId, nSessionId) = False) then
      Exit();

    bProcessed := True;

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class function TVaxRingGroup.AddRingGroup(sGroupName: String; nProcessMode: Integer; nProcessType: Integer; objAgentList: TStringList): Boolean;
  var
    sAgentName: String;
  begin

    if((TVaxServerSIP.mVaxSIP.IsInitialized() = False) or (Length(sGroupName) = 0)) Then
      Exit(False);

    RemoveRingGroup(sGroupName);

    if(TVaxServerSIP.mVaxSIP.AddRingGroup(sGroupName) = False) Then
      Exit(False);

    for sAgentName in objAgentList do
    begin
      TVaxServerSIP.mVaxSIP.AddRingGroupAgent(sGroupName, sAgentName);
    end;

    TVaxServerSIP.mVaxSIP.SetRingGroupProcessMode(sGroupName, nProcessMode, nProcessType);
    TStoreRingGroup.AddGroup(sGroupName, nProcessMode, nProcessType, objAgentList);

    Result := True;

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TVaxRingGroup.RemoveRingGroup(sGroupName: String);
  begin

    if((TVaxServerSIP.mVaxSIP.IsInitialized() = False) or (Length(sGroupName) = 0)) Then
      Exit();

    TVaxServerSIP.mVaxSIP.RemoveRingGroup(sGroupName);
    TStoreRingGroup.RemoveGroup(sGroupName);

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TVaxRingGroup.LoadRingGroup();
  var
    sRingGroupName: String;
    nProcessMode, nProcessType: Integer;

    objListRingGroup: TStringList;
    objAgentList: TStringList;
  begin

    if(TVaxServerSIP.mVaxSIP.IsInitialized() = False) Then
      Exit();

    objListRingGroup := TStringList.Create();
    TStoreRingGroup.GetGroupNameAll(objListRingGroup);

    if(objListRingGroup.Count = 0) Then
      Exit();

    objAgentList :=  TStringList.Create();
    nProcessMode := -1; nProcessType := -1;

    for sRingGroupName in objListRingGroup do
    begin
      TStoreRingGroup.GetGroup(sRingGroupName, nProcessMode, nProcessType, objAgentList);
      AddRingGroup(sRingGroupName, nProcessMode, nProcessType, objAgentList);
    end;

  end;

end.
