unit VaxSettingDefault;

Interface

Uses

  System.Classes, System.SysUtils, System.Variants,

  StoreUser, StoreLine, StoreCOMM, StoreRoom,
  StoreQueue, StoreRingGroup, StoreCallPickUp;

type TVaxSettingDefault = class

  public
  constructor Create();

  class function LoadUserDefault(): Boolean; static;
  class function LoadQueueDefault(): Boolean; static;

  class function LoadRingGroupDefault(): Boolean; static;
  class function LoadCallPickUpGroupDefault(): Boolean; static;

  class function LoadLineDefault(): Boolean; static;
  class function LoadRoomDefault(): Boolean; static;

end;

implementation

uses VaxUser, VaxLine, VaxRoom, VaxQueue, VaxRingGroup, VaxCallPickUp,
     VaxDefine, VaxServerCOM, VaxServerSIP;

  //////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////

  constructor TVaxSettingDefault.Create();
  begin
  end;

  //////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////

  class function TVaxSettingDefault.LoadUserDefault(): Boolean;
  var
    sAuthLogin, sAuthPwd: string;
    nCount: Integer;
  begin

    if (TStoreUser.IsDataStored() = True) then
      Exit(False);

    for nCount := 4000 to 4050 do
    begin
      sAuthLogin := IntToStr(nCount);
      sAuthPwd := sAuthLogin;
      TVaxUser.AddUser(sAuthLogin, sAuthPwd, '32014', False, TVaxServerCOM.VAX_AUDIO_TYPE_NORMAL, '', '', '')
    end;

    for nCount := 6000 to 6020 do
    begin
      sAuthLogin := IntToStr(nCount);
      sAuthPwd := sAuthLogin;
      TVaxUser.AddUser(sAuthLogin, sAuthPwd, '32014', False, TVaxServerCOM.VAX_AUDIO_TYPE_USER, '', '', '')
    end;

    for nCount := 8000 to 8020 do
    begin
      sAuthLogin := IntToStr(nCount);
      sAuthPwd := sAuthLogin;
      TVaxUser.AddUser(sAuthLogin, sAuthPwd, '32014', False, TVaxServerCOM.VAX_AUDIO_TYPE_ADMIN, '', '', '')
    end;

    Result := True;

  end;

  //////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////

  class function TVaxSettingDefault.LoadQueueDefault(): Boolean;
  var
    objAgentList: TStringList;
  begin

    if (TStoreQueue.IsDataStored() = True) then
      Exit(False);

    objAgentList :=  TStringList.Create();

    objAgentList.Add('6000');
	  objAgentList.Add('6001');
	  objAgentList.Add('6002');
	  objAgentList.Add('6003');
	  objAgentList.Add('6004');
	  objAgentList.Add('6005');

    TVaxQueue.AddQueue('QueueTech', TVaxServerCOM.VAX_QUEUE_PROCESS_MODE_ROUND_ROBIN, TVaxServerCOM.VAX_QUEUE_PROCESS_TYPE_FREE, objAgentList, TVaxDefine.MUSIC_FILE_QUEUE, TVaxDefine.MUSIC_FILE_DIAL_TONE);

    objAgentList.Clear();

    objAgentList.Add('6010');
	  objAgentList.Add('6011');
	  objAgentList.Add('6012');
	  objAgentList.Add('6013');
	  objAgentList.Add('6014');
	  objAgentList.Add('6015');

    TVaxQueue.AddQueue('QueueSales', TVaxServerCOM.VAX_QUEUE_PROCESS_MODE_HUNT_RANDOM, TVaxServerCOM.VAX_QUEUE_PROCESS_TYPE_FREE, objAgentList, TVaxDefine.MUSIC_FILE_QUEUE, TVaxDefine.MUSIC_FILE_DIAL_TONE);

    Result := True;

  end;

  class function TVaxSettingDefault.LoadRingGroupDefault(): Boolean;
  var
    objAgentList: TStringList;
  begin

    if (TStoreRingGroup.IsDataStored() = True) then
      Exit(False);

    objAgentList :=  TStringList.Create();

    objAgentList.Add('4000');
	  objAgentList.Add('4001');
	  objAgentList.Add('4002');
	  objAgentList.Add('4003');
	  objAgentList.Add('4004');
	  objAgentList.Add('4005');

    TVaxRingGroup.AddRingGroup('RingGroupTech', TVaxServerCOM.VAX_RING_GROUP_PROCESS_MODE_RING_ALL, TVaxServerCOM.VAX_RING_GROUP_PROCESS_TYPE_FREE, objAgentList);

    objAgentList.Clear();

    objAgentList.Add('4010');
	  objAgentList.Add('4011');
	  objAgentList.Add('4012');
	  objAgentList.Add('4013');
	  objAgentList.Add('4014');
	  objAgentList.Add('4015');

    TVaxRingGroup.AddRingGroup('RingGroupDesign', TVaxServerCOM.VAX_RING_GROUP_PROCESS_MODE_HUNT_RANDOM, TVaxServerCOM.VAX_RING_GROUP_PROCESS_TYPE_FREE, objAgentList);

    Result := True;

  end;

  class function TVaxSettingDefault.LoadCallPickUpGroupDefault(): Boolean;
  var
    objMemberList: TStringList;
  begin

    if (TStoreCallPickUp.IsDataStored() = True) then
      Exit(False);

    objMemberList :=  TStringList.Create();

    objMemberList.Add('4000');
	  objMemberList.Add('4001');
	  objMemberList.Add('4002');
	  objMemberList.Add('4003');
	  objMemberList.Add('4004');
	  objMemberList.Add('4005');

    TVaxCallPickUp.AddCallPickUpGroup('PickUpTech', objMemberList);

    objMemberList.Clear();

    objMemberList.Add('4010');
	  objMemberList.Add('4011');
	  objMemberList.Add('4012');
	  objMemberList.Add('4013');
	  objMemberList.Add('4014');
	  objMemberList.Add('4015');

    TVaxCallPickUp.AddCallPickUpGroup('PickUpDesign', objMemberList);

    Result := True;

  end;

  //////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////

  class function TVaxSettingDefault.LoadLineDefault(): Boolean;
  begin

    if (TStoreLine.IsDataStored() = True) then
      Exit(False);

    TVaxLine.AddLine('LineServiceProviderTech', TVaxServerCOM.VAX_LINE_TYPE_UDP, '9090', '9090', '192.168.0.119', 5060, '32', False, '', False, '', 'QueueTech', '');
    TVaxLine.AddLine('LineServiceProviderDesign', TVaxServerCOM.VAX_LINE_TYPE_UDP, '9092', '9092', '192.168.0.119', 5060, '32', False, '', False, '', 'QueueSales', '');

    Result := True;

  end;

   //////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////

  class function TVaxSettingDefault.LoadRoomDefault(): Boolean;
  begin

    if (TStoreRoom.IsDataStored() = True) then
      Exit(False);

    TVaxRoom.AddRoom('RoomTech', '20021');
    TVaxRoom.AddRoom('RoomDesign', '20022');

    Result := True;
  end;

end.
