﻿unit StoreCallPickUp;

Interface

uses

  Winapi.Windows, Winapi.Messages,
  System.SysUtils, System.Classes,
  StoreRegistry, VaxServerCOM;

type TStoreCallPickUp = class

  private
  const CALL_PICKUP_GROUP_ROOT_PATH = 'CallPickUpGroups\\';

  public
  class function AddGroup(sGroupName: String; objMemberList: TStringList): Boolean; static;
  class procedure RemoveGroup(sGroupName: String); static;

  public
  class function GetGroup(sGroupName: String; var objMemberList: TStringList): Boolean; static;
  class procedure GetGroupNameAll(var objList: TStringList); static;

  private
  class function AddGroupMember(sGroupName: String; sUserName: String): Boolean; static;
  class procedure GetMemberNameAll(sGroupName: String; var objList: TStringList); static;

  public
  class function IsDataStored(): Boolean; static;

end;


implementation

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class function TStoreCallPickUp.AddGroup(sGroupName: String; objMemberList: TStringList): Boolean;
  var
    sKeyPath: String;
    sMemberName: String;
    objStore: TStoreRegistry;
  begin

    if Length(sGroupName) = 0 then
    begin
      Exit(False);
    end;

    sKeyPath := CALL_PICKUP_GROUP_ROOT_PATH + sGroupName;
    objStore := TStoreRegistry.Create();

    objStore.SetTEXT(sKeyPath, 'CallPickUpGroupName', sGroupName);

    for sMemberName in objMemberList do
    begin
      AddGroupMember(sGroupName, sMemberName);
    end;

    objStore.Destroy();
    Result := True;

  end;

  class procedure TStoreCallPickUp.RemoveGroup(sGroupName: String);
  var
    sKeyPath: String;
    objStore: TStoreRegistry;
  begin

    if Length(sGroupName) = 0 then
    begin
      Exit();
    end;

    sKeyPath := CALL_PICKUP_GROUP_ROOT_PATH + sGroupName;
    objStore := TStoreRegistry.Create();

    objStore.DeleteSubKey(sKeyPath);
    objStore.Destroy();

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class function TStoreCallPickUp.GetGroup(sGroupName: String; var objMemberList: TStringList): Boolean;
  begin

    if Length(sGroupName) = 0 then
    begin
      Exit(False);
    end;

    GetMemberNameAll(sGroupName, objMemberList);
    Result := True;

  end;

  class procedure TStoreCallPickUp.GetGroupNameAll(var objList: TStringList);
  var
    sKeyPath: String;
    objStore: TStoreRegistry;
  begin

    objList.Clear();

    sKeyPath := CALL_PICKUP_GROUP_ROOT_PATH;
    objStore := TStoreRegistry.Create();

    objStore.EnumSubKeys(sKeyPath, objList);
    objStore.Destroy();

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class function TStoreCallPickUp.AddGroupMember(sGroupName: String; sUserName: String): Boolean;
  var
    sKeyPath: String;
    objStore: TStoreRegistry;
  begin

    if (Length(sGroupName) = 0) or (Length(sUserName) = 0) then
    begin
      Exit(False);
    end;

    sKeyPath := CALL_PICKUP_GROUP_ROOT_PATH + sGroupName + '\\' + sUserName;
    objStore := TStoreRegistry.Create();

    objStore.SetTEXT(sKeyPath, 'UserName', sGroupName);
    objStore.Destroy();

    Result := True;

  end;

  class procedure TStoreCallPickUp.GetMemberNameAll(sGroupName: String; var objList: TStringList);
  var
    sKeyPath: String;
    objStore: TStoreRegistry;
  begin

    objList.Clear();

    if Length(sGroupName) = 0 then
    begin
      Exit();
    end;

    sKeyPath := CALL_PICKUP_GROUP_ROOT_PATH + sGroupName;
    objStore := TStoreRegistry.Create();

    objStore.EnumSubKeys(sKeyPath, objList);
    objStore.Destroy();

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class function TStoreCallPickUp.IsDataStored(): Boolean;
  var
    objStore: TStoreRegistry;
  begin
    objStore := TStoreRegistry.Create();
    Result := objStore.IsKeyExist(CALL_PICKUP_GROUP_ROOT_PATH);
    objStore.Destroy();
  end;

end.
