﻿unit StoreQueue;

Interface

uses

  Winapi.Windows,
  Winapi.Messages,
  System.SysUtils,
  System.Classes,
  StoreRegistry, VaxServerCOM, VaxDefine;

type TStoreQueue = class

  private
  const QUEUE_ROOT_PATH = 'Queues\\';

  public
  class function AddQueue(sQueueName: String; nProcessMode: Integer; nProcessType: Integer; objAgentList: TStringList; sMusicFileName: String; sDialToneFileName: String): Boolean; static;
  class function GetQueue(sQueueName: String; var nProcessMode: Integer; var nProcessType: Integer; var objAgentList: TStringList; var sMusicFileName: String; var sDialToneFileName: String): Boolean; static;

  class procedure RemoveQueue(sQueueName: String); static;
  class procedure GetQueueNameAll(var objList: TStringList); static;

  private
  class function SetMediaFiles(sQueueName: String; sMusicFileName: String; sDialToneFileName: String): Boolean; static;
  class procedure GetMediaFiles(sQueueName: String; var sMusicFileName: String; var sDialToneFileName: String); static;

  class function SetQueueProcessMode(sQueueName: String; nProcessMode: Integer; nProcessType: Integer): Boolean; static;
  class procedure GetQueueProcessMode(sQueueName: String; var nProcessMode: Integer; var nProcessType: Integer); static;

  class procedure AddQueueAgentNameAll(sQueueName: String; objList: TStringList); static;
  class procedure GetQueueAgentNameAll(sQueueName: String; var objList: TStringList); static;

  public
  class function IsDataStored(): Boolean; static;

end;


implementation

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class function TStoreQueue.AddQueue(sQueueName: String; nProcessMode: Integer; nProcessType: Integer; objAgentList: TStringList; sMusicFileName: String; sDialToneFileName: String): Boolean;
  var
    sKeyPath: String;
    objStore: TStoreRegistry;
  begin

    if Length(sQueueName) = 0 then
    begin
      Exit(False);
    end;

    sKeyPath := QUEUE_ROOT_PATH + sQueueName;
    objStore := TStoreRegistry.Create();

    objStore.SetTEXT(sKeyPath, 'QueueName', sQueueName);

    AddQueueAgentNameAll(sQueueName, objAgentList);

    SetQueueProcessMode(sQueueName, nProcessMode, nProcessType);
    SetMediaFiles(sQueueName, sMusicFileName, sDialToneFileName);

    objStore.Destroy();
    Result := True;

  end;

  class procedure TStoreQueue.RemoveQueue(sQueueName: String);
  var
    sKeyPath: String;
    objStore: TStoreRegistry;
  begin

    if Length(sQueueName) = 0 then
    begin
      Exit();
    end;

    sKeyPath := QUEUE_ROOT_PATH + sQueueName;
    objStore := TStoreRegistry.Create();

    objStore.DeleteSubKey(sKeyPath);
    objStore.Destroy();

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class function TStoreQueue.GetQueue(sQueueName: String; var nProcessMode: Integer; var nProcessType: Integer; var objAgentList: TStringList; var sMusicFileName: String; var sDialToneFileName: String): Boolean;
  begin

    GetQueueProcessMode(sQueueName, nProcessMode, nProcessType);
    GetQueueAgentNameAll(sQueueName, objAgentList);

    GetMediaFiles(sQueueName, sMusicFileName, sDialToneFileName);

    Result := True;

  end;

  class procedure TStoreQueue.GetQueueNameAll(var objList: TStringList);
  var
    sKeyPath: String;
    objStore: TStoreRegistry;
  begin

    sKeyPath := QUEUE_ROOT_PATH;
    objStore := TStoreRegistry.Create();

    objStore.EnumSubKeys(sKeyPath, objList);
    objStore.Destroy();

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class function TStoreQueue.SetQueueProcessMode(sQueueName: String; nProcessMode: Integer; nProcessType: Integer): Boolean;
  var
    sKeyPath: String;
    objStore: TStoreRegistry;
  begin

    sKeyPath := QUEUE_ROOT_PATH + sQueueName;
    objStore := TStoreRegistry.Create();

    objStore.SetINT(sKeyPath, 'ProcessMode', nProcessMode);
    objStore.SetINT(sKeyPath, 'ProcessType', nProcessType);

    objStore.Destroy();
    Result := True;

  end;

  class procedure TStoreQueue.GetQueueProcessMode(sQueueName: String; var nProcessMode: Integer; var nProcessType: Integer);
  var
    sKeyPath: String;
    objStore: TStoreRegistry;
  begin

    sKeyPath := QUEUE_ROOT_PATH + sQueueName;
    objStore := TStoreRegistry.Create();

    objStore.GetINT(sKeyPath, 'ProcessMode', nProcessMode, TVaxServerCOM.VAX_QUEUE_PROCESS_MODE_ROUND_ROBIN);
    objStore.GetINT(sKeyPath, 'ProcessType', nProcessType, TVaxServerCOM.VAX_QUEUE_PROCESS_TYPE_FREE);

    objStore.Destroy();

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class function TStoreQueue.SetMediaFiles(sQueueName: String; sMusicFileName: String; sDialToneFileName: String): Boolean;
  var
    sKeyPath: String;
    objStore: TStoreRegistry;
  begin

    sKeyPath := QUEUE_ROOT_PATH + sQueueName;
    objStore := TStoreRegistry.Create();

    objStore.SetTEXT(sKeyPath, 'MusicFileName', sMusicFileName);
    objStore.SetTEXT(sKeyPath, 'DialToneFileName', sDialToneFileName);

    objStore.Destroy();
    Result := True;

  end;

  class procedure TStoreQueue.GetMediaFiles(sQueueName: String; var sMusicFileName: String; var sDialToneFileName: String);
  var
    sKeyPath: String;
    objStore: TStoreRegistry;
  begin

    sKeyPath := QUEUE_ROOT_PATH + sQueueName;
    objStore := TStoreRegistry.Create();

    objStore.GetTEXT(sKeyPath, 'MusicFileName', sMusicFileName, TVaxDefine.MUSIC_FILE_QUEUE);
    objStore.GetTEXT(sKeyPath, 'DialToneFileName', sDialToneFileName, TVaxDefine.MUSIC_FILE_DIAL_TONE);

    objStore.Destroy();

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TStoreQueue.AddQueueAgentNameAll(sQueueName: String; objList: TStringList);
  var
    sKeyPath, sUserName: String;
    objStore: TStoreRegistry;
  begin

    if Length(sQueueName) = 0 then
    begin
      Exit();
    end;

    objStore := TStoreRegistry.Create();

    for sUserName in objList do
    begin
      sKeyPath := QUEUE_ROOT_PATH + sQueueName + '\\' + sUserName;
      objStore.SetTEXT(sKeyPath, 'UserName', sUserName);
    end;

    objStore.Destroy();

  end;

  class procedure TStoreQueue.GetQueueAgentNameAll(sQueueName: String; var objList: TStringList);
  var
    sKeyPath: String;
    objStore: TStoreRegistry;
  begin

    sKeyPath := QUEUE_ROOT_PATH + sQueueName;
    objStore := TStoreRegistry.Create();

    objStore.EnumSubKeys(sKeyPath, objList);
    objStore.Destroy();

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////


  class function TStoreQueue.IsDataStored(): Boolean;
  var
    objStore: TStoreRegistry;
  begin
    objStore := TStoreRegistry.Create();
    Result := objStore.IsKeyExist(QUEUE_ROOT_PATH);
    objStore.Destroy();
  end;

end.
