﻿unit StoreRingGroup;

Interface

uses

  Winapi.Windows, Winapi.Messages,
  System.SysUtils, System.Classes,
  StoreRegistry, VaxServerCOM;

type TStoreRingGroup = class

  private
  const RING_GROUP_ROOT_PATH = 'RingGroups\\';

  public
  class function AddGroup(sGroupName: String; nProcessMode: Integer; nProcessType: Integer; objAgentList: TStringList): Boolean; static;
  class procedure RemoveGroup(sGroupName: String); static;

  class function GetGroup(sGroupName: String; var nProcessMode: Integer; var nProcessType: Integer; var objAgentList: TStringList): Boolean; static;
  class procedure GetGroupNameAll(var objList: TStringList); static;

  private
  class function SetGroupProcessMode(sGroupName: String; nProcessMode: Integer; nProcessType: Integer): Boolean; static;
  class function GetGroupProcessMode(sGroupName: String; var nProcessMode: Integer; var nProcessType: Integer): Boolean; static;

  class procedure AddGroupAgentNameAll(sGroupName: String; objList: TStringList); static;
  class procedure GetGroupAgentNameAll(sGroupName: String; var objList: TStringList); static;

  public
  class function IsDataStored(): Boolean; static;

end;


implementation

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class function TStoreRingGroup.AddGroup(sGroupName: String; nProcessMode: Integer; nProcessType: Integer; objAgentList: TStringList): Boolean;
  var
    sKeyPath: String;
    objStore: TStoreRegistry;
  begin

    if Length(sGroupName) = 0 then
    begin
      Exit(False);
    end;

    sKeyPath := RING_GROUP_ROOT_PATH + sGroupName;
    objStore := TStoreRegistry.Create();

    objStore.SetTEXT(sKeyPath, 'RingGroupName', sGroupName);

    AddGroupAgentNameAll(sGroupName, objAgentList);
    SetGroupProcessMode(sGroupName, nProcessMode, nProcessType);

    objStore.Destroy();
    Result := True;

  end;

  class procedure TStoreRingGroup.RemoveGroup(sGroupName: String);
  var
    sKeyPath: String;
    objStore: TStoreRegistry;
  begin

    if Length(sGroupName) = 0 then
    begin
      Exit();
    end;

    sKeyPath := RING_GROUP_ROOT_PATH + sGroupName;
    objStore := TStoreRegistry.Create();

    objStore.DeleteSubKey(sKeyPath);
    objStore.Destroy();

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class function TStoreRingGroup.GetGroup(sGroupName: String; var nProcessMode: Integer; var nProcessType: Integer; var objAgentList: TStringList): Boolean;
  begin

    if Length(sGroupName) = 0 then
    begin
      Exit(False);
    end;

    GetGroupProcessMode(sGroupName, nProcessMode, nProcessType);
    GetGroupAgentNameAll(sGroupName, objAgentList);

    Result := True;

  end;

  class procedure TStoreRingGroup.GetGroupNameAll(var objList: TStringList);
  var
    sKeyPath: String;
    objStore: TStoreRegistry;
  begin

    sKeyPath := RING_GROUP_ROOT_PATH;
    objStore := TStoreRegistry.Create();

    objStore.EnumSubKeys(sKeyPath, objList);
    objStore.Destroy();

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class function TStoreRingGroup.SetGroupProcessMode(sGroupName: String; nProcessMode: Integer; nProcessType: Integer): Boolean;
  var
    sKeyPath: String;
    objStore: TStoreRegistry;
  begin

    sKeyPath := RING_GROUP_ROOT_PATH + sGroupName;
    objStore := TStoreRegistry.Create();

    objStore.SetINT(sKeyPath, 'ProcessMode', nProcessMode);
    objStore.SetINT(sKeyPath, 'ProcessType', nProcessType);

    objStore.Destroy();
    Result := True;

  end;

  class function TStoreRingGroup.GetGroupProcessMode(sGroupName: String; var nProcessMode: Integer; var nProcessType: Integer): Boolean;
  var
    sKeyPath: String;
    objStore: TStoreRegistry;
  begin

    sKeyPath := RING_GROUP_ROOT_PATH + sGroupName;
    objStore := TStoreRegistry.Create();

    objStore.GetINT(sKeyPath, 'ProcessMode', nProcessMode, TVaxServerCOM.VAX_RING_GROUP_PROCESS_MODE_RING_ALL);
    objStore.GetINT(sKeyPath, 'ProcessType', nProcessType, TVaxServerCOM.VAX_RING_GROUP_PROCESS_TYPE_FREE);

    objStore.Destroy();
    Result := True;

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class procedure TStoreRingGroup.AddGroupAgentNameAll(sGroupName: String; objList: TStringList);
  var
    sKeyPath, sUserName: String;
    objStore: TStoreRegistry;
  begin

    if Length(sGroupName) = 0 then
    begin
      Exit();
    end;

    objStore := TStoreRegistry.Create();

    for sUserName in objList do
    begin
      sKeyPath := RING_GROUP_ROOT_PATH + sGroupName + '\\' + sUserName;
      objStore.SetTEXT(sKeyPath, 'UserName', sUserName);
    end;

    objStore.Destroy();

  end;

  class procedure TStoreRingGroup.GetGroupAgentNameAll(sGroupName: String; var objList: TStringList);
  var
    sKeyPath: String;
    objStore: TStoreRegistry;
  begin

    sKeyPath := RING_GROUP_ROOT_PATH + sGroupName;
    objStore := TStoreRegistry.Create();

    objStore.EnumSubKeys(sKeyPath, objList);
    objStore.Destroy();

  end;

  //////////////////////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////

  class function TStoreRingGroup.IsDataStored(): Boolean;
  var
    objStore: TStoreRegistry;
  begin
    objStore := TStoreRegistry.Create();
    Result := objStore.IsKeyExist(RING_GROUP_ROOT_PATH);
    objStore.Destroy();
  end;

end.
